Class: Object

Inherits:
BasicObject
Defined in:
lib/object_extension.rb

Instance Method Summary collapse

Instance Method Details

#functional_tests(options = {}, &block) ⇒ Object

call-seq: functional_tests(options={}, &block)

Used to define a block of functional tests.

functional_tests do
 test "verify something" do                                   
   ...
 end                                                     
end                                                       

Configuration Options:

  • allow - Allows you to specify the methods that are allowed despite being disallowed.
    See Test::Unit::TestCase.disallow_helpers! or Test::Unit::TestCase.disallow_setup! for more info


32
33
34
# File 'lib/object_extension.rb', line 32

def functional_tests(options={}, &block)
  do_tests("Functionals", options, &block)
end

#unit_tests(options = {}, &block) ⇒ Object

call-seq: unit_tests(options={}, &block)

Used to define a block of unit tests.

unit_tests do
 test "verify something" do                                   
   ...
 end                                                     
end                 

Configuration Options:

  • allow - Allows you to specify the methods that are allowed despite being disallowed.
    See Test::Unit::TestCase.disallow_helpers! or Test::Unit::TestCase.disallow_setup! for more info


15
16
17
# File 'lib/object_extension.rb', line 15

def unit_tests(options={}, &block)
  do_tests("Units", options, &block)
end